# importieren der zusätzlichen Module
from dht_sensor import DHT11
from website import *

# importieren der Module für den Aufbau
# der Netzwerkverbindung und die Möglichkeit
# eine Webseite auszuliefern
import network
import socket

# Modul welches Funktionen zur Zeiten bereithält
# zbsp. wieviele Millisekunden seit dem Start
# vergangen sind
import time

# Modul für das steuern der GPIOs am Mikrocontroller
from machine import Pin

# erzeugen einer Instanz des DHT11 Sensors
sensor = DHT11()

# Zugangsdaten zum WiFi Netzwerk
ssid = '***'
password = '***'

# Aufbauen einer WiFi Verbindung
wlan = network.WLAN(network.STA_IF)
wlan.active(True)
wlan.connect(ssid, password)

print('Verbindung wird aufgebaut...')
max_wait = 10
while max_wait > 0:
    if wlan.status() < 0 or wlan.status() >= 3:
        break
    max_wait -= 1
    print('.', end='')
    time.sleep(1)

print('')

if wlan.status() != 3:
    raise RuntimeError('Aufbau der Verbindung fehlgeschlagen!')
else:
    print('Erfolgreich mit dem WiFi Netzwerk ', ssid, ' verbunden!' )
    status = wlan.ifconfig()
    print('aktuelle IP-Adresse ist: ' + status[0])

addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]

s = socket.socket()
s.bind(addr)
s.listen(1)

# print('', addr)

# Variablen für das speichern der letzten Ausführung
# zum lesen der Messdaten vom Sensor
last_action = 0

# Wert in Millisekunden
delay = 1500

# ein Zähler welcher hochgezählt wird
data_index = 0

# Variable für das halten der Webseite
html_data = ""

# Endlosschleife
while True:
    # Wenn der Zeitpunkt der letzten Ausführung länger zurück liegt,
    # als der jetzige Zeitpunkt - dem gesetzen delay, dann...
    if last_action < (time.ticks_ms()-delay):
        last_action = time.ticks_ms()     
        data_index = data_index + 1
        # lesen der Sensordaten
        sensor.readSensordata(data_index)
        line_data = "[\"{i}\", {t}, {h}],"
        sensor_data = ""
        # loop über die bisher gespeicherten Daten
        for data in sensor.recorded_data:
            # ein Eintrag aus der Liste enthält:
            # - einen Index,
            # - die Temperatur,
            # - die rel. Luftfeuchtigkeit
            index, temp, hum = data
            # formatieren der Daten
            sensor_data = sensor_data + line_data.format(i=index, t=temp, h=hum)
            # verbinden der Webseite Teil1 & Teil2 inkl. Daten
            html_data = html_part1 + sensor_data[:-1] + html_part2
    
    try:
        # Wenn ein Client verbunden wurde dann die Daten ausliefern.
        cl, addr = s.accept()
        print('Mit dem Client ', addr, ' verbunden.', addr)      
        
        cl.send('HTTP/1.0 200 OK\r\nContent-type: text/html\r\n\r\n')
        cl.send(html_data)
        cl.close()

    except OSError as e:
        cl.close()
        print('Verbindung geschlossen')


